python-mailutil - Python module for sending e-mail via SMTP
===========================================================

This module package is mainly used by components of [Æ-DIR](https://ae-dir.com).

It implements:

  * wrapper classes for smtplib.SMTP with better TLS support
  * factory function which opens SMTP connections described by URL

This module package requires Python 3.6 or newer.

Project resources:

  * [git repo python-mailutil](https://code.stroeder.com/pymod/python-mailutil)
  * [PyPI](https://pypi.python.org/pypi/mailutil)
  * [openSUSE/SLE packages](https://build.opensuse.org/package/show/home:stroeder:iam/python-mailutil)
